pkgsrc-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[pkgsrc/trunk]: pkgsrc/mail/qmail-run Wrap (or shorten) long lines. Parameter...



details:   https://anonhg.NetBSD.org/pkgsrc/rev/0ebda0742c95
branches:  trunk
changeset: 360923:0ebda0742c95
user:      schmonz <schmonz%pkgsrc.org@localhost>
date:      Mon Apr 10 15:04:56 2017 +0000

description:
Wrap (or shorten) long lines. Parameterize some qmailqread config to
match other scripts. Bump version.

diffstat:

 mail/qmail-run/Makefile             |   4 ++--
 mail/qmail-run/files/qmailofmipd.sh |  19 ++++++++++++++-----
 mail/qmail-run/files/qmailpop3d.sh  |  17 +++++++++++++----
 mail/qmail-run/files/qmailqread.sh  |  19 +++++++++++++++----
 mail/qmail-run/files/qmailsend.sh   |  10 ++++++----
 mail/qmail-run/files/qmailsmtpd.sh  |  17 +++++++++++++----
 6 files changed, 63 insertions(+), 23 deletions(-)

diffs (188 lines):

diff -r ed1c9cf3130e -r 0ebda0742c95 mail/qmail-run/Makefile
--- a/mail/qmail-run/Makefile   Mon Apr 10 13:24:55 2017 +0000
+++ b/mail/qmail-run/Makefile   Mon Apr 10 15:04:56 2017 +0000
@@ -1,7 +1,7 @@
-# $NetBSD: Makefile,v 1.33 2017/04/09 12:58:46 schmonz Exp $
+# $NetBSD: Makefile,v 1.34 2017/04/10 15:04:56 schmonz Exp $
 #
 
-DISTNAME=              qmail-run-20170409
+DISTNAME=              qmail-run-20170410
 CATEGORIES=            mail
 MASTER_SITES=          # empty
 DISTFILES=             # empty
diff -r ed1c9cf3130e -r 0ebda0742c95 mail/qmail-run/files/qmailpop3d.sh
--- a/mail/qmail-run/files/qmailpop3d.sh        Mon Apr 10 13:24:55 2017 +0000
+++ b/mail/qmail-run/files/qmailpop3d.sh        Mon Apr 10 15:04:56 2017 +0000
@@ -1,6 +1,6 @@
 #!@RCD_SCRIPTS_SHELL@
 #
-# $NetBSD: qmailpop3d.sh,v 1.12 2017/04/09 12:58:46 schmonz Exp $
+# $NetBSD: qmailpop3d.sh,v 1.13 2017/04/10 15:04:56 schmonz Exp $
 #
 # @PKGNAME@ script to control qmail-pop3d (POP3 server for Maildirs).
 #
@@ -46,10 +46,19 @@
        # tcpserver(1) is akin to inetd(8), but runs one service per process.
        # We want to signal only the tcpserver process responsible for POP
        # service. Use argv0(1) to set procname to "qmailpop3d".
-       if [ -f /etc/rc.subr ]; then
-               checkyesno qmailpop3d_log || qmailpop3d_logcmd=${qmailpop3d_nologcmd}
+       if [ -f /etc/rc.subr ] && ! checkyesno qmailpop3d_log; then
+               qmailpop3d_logcmd=${qmailpop3d_nologcmd}
        fi
-       command="@SETENV@ - ${qmailpop3d_postenv} @PREFIX@/bin/softlimit -m ${qmailpop3d_datalimit} ${qmailpop3d_pretcpserver} @PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name} ${qmailpop3d_tcpflags} 
-x @PKG_SYSCONFDIR@/tcp.pop3.cdb -c `@HEAD@ -1 @PKG_SYSCONFDIR@/control/concurrencypop3` ${qmailpop3d_tcphost} ${qmailpop3d_tcpport} @PREFIX@/bin/qmail-popup `@HEAD@ -1 @PKG_SYSCONFDIR@/control/me` 
${qmailpop3d_checkpassword} ${qmailpop3d_prepop3d} ${qmailpop3d_pop3dcmd} ${qmailpop3d_maildirname} 2>&1 | @PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailpop3d_logcmd}"
+       command="@SETENV@ - ${qmailpop3d_postenv}
+@PREFIX@/bin/softlimit -m ${qmailpop3d_datalimit} ${qmailpop3d_pretcpserver}
+@PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name}
+${qmailpop3d_tcpflags} -x @PKG_SYSCONFDIR@/tcp.pop3.cdb
+-c `@HEAD@ -1 @PKG_SYSCONFDIR@/control/concurrencypop3`
+${qmailpop3d_tcphost} ${qmailpop3d_tcpport} @PREFIX@/bin/qmail-popup
+`@HEAD@ -1 @PKG_SYSCONFDIR@/control/me` ${qmailpop3d_checkpassword}
+${qmailpop3d_prepop3d} ${qmailpop3d_pop3dcmd} ${qmailpop3d_maildirname}
+2>&1 |
+@PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailpop3d_logcmd}"
        command_args="&"
        rc_flags=""
 }
diff -r ed1c9cf3130e -r 0ebda0742c95 mail/qmail-run/files/qmailqread.sh
--- a/mail/qmail-run/files/qmailqread.sh        Mon Apr 10 13:24:55 2017 +0000
+++ b/mail/qmail-run/files/qmailqread.sh        Mon Apr 10 15:04:56 2017 +0000
@@ -1,6 +1,6 @@
 #!@RCD_SCRIPTS_SHELL@
 #
-# $NetBSD: qmailqread.sh,v 1.9 2017/04/04 07:51:03 schmonz Exp $
+# $NetBSD: qmailqread.sh,v 1.10 2017/04/10 15:04:56 schmonz Exp $
 #
 # @PKGNAME@ script to control a service providing local non-root
 # users access to see the queue. Adapted from a script by Steinar Haug.
@@ -12,6 +12,10 @@
 name="qmailqread"
 
 # User-settable rc.conf variables and their default values:
+: ${qmailqread_postenv:=""}
+: ${qmailqread_tcpflags:="-R1"}
+: ${qmailqread_tcphost:="127.0.0.1"}
+: ${qmailqread_tcpport:="20025"}
 : ${qmailqread_log:="YES"}
 : ${qmailqread_logcmd:="logger -t nb${name} -p mail.info"}
 : ${qmailqread_nologcmd:="@PREFIX@/bin/multilog -*"}
@@ -27,10 +31,17 @@
 
 qmailqread_precmd()
 {
-       if [ -f /etc/rc.subr ]; then
-               checkyesno qmailqread_log || qmailqread_logcmd=${qmailqread_nologcmd}
+       if [ -f /etc/rc.subr ] && ! checkyesno qmailqread_log; then
+               qmailqread_logcmd=${qmailqread_nologcmd}
        fi
-       command="@SETENV@ - @PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name} -R -1 -u `@ID@ -u @QMAIL_SEND_USER@` -g `@ID@ -g @QMAIL_SEND_USER@` 127.0.0.1 20025 @PREFIX@/bin/qmail-qread 2>&1 | 
@PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailqread_logcmd}"
+       command="@SETENV@ - ${qmailqread_postenv}
+@PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name}
+${qmailqread_tcpflags}
+-u `@ID@ -u @QMAIL_SEND_USER@` -g `@ID@ -g @QMAIL_SEND_USER@`
+${qmailqread_tcphost} ${qmailqread_tcpport}
+@PREFIX@/bin/qmail-qread
+2>&1 |
+@PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailqread_logcmd}"
        command_args="&"
        rc_flags=""
 }
diff -r ed1c9cf3130e -r 0ebda0742c95 mail/qmail-run/files/qmailsend.sh
--- a/mail/qmail-run/files/qmailsend.sh Mon Apr 10 13:24:55 2017 +0000
+++ b/mail/qmail-run/files/qmailsend.sh Mon Apr 10 15:04:56 2017 +0000
@@ -1,6 +1,6 @@
 #!@RCD_SCRIPTS_SHELL@
 #
-# $NetBSD: qmailsend.sh,v 1.8 2015/11/25 12:51:30 jperkin Exp $
+# $NetBSD: qmailsend.sh,v 1.9 2017/04/10 15:04:56 schmonz Exp $
 #
 # @PKGNAME@ script to control qmail-send (local and outgoing mail).
 #
@@ -41,10 +41,12 @@
 {
        # qmail-start(8) starts the various qmail processes, then exits.
        # qmail-send(8) is the process we want to signal later.
-       if [ -f /etc/rc.subr ]; then
-               checkyesno qmailsend_log || qmailsend_logcmd=${qmailsend_nologcmd}
+       if [ -f /etc/rc.subr ] && ! checkyesno qmailsend_log; then
+               qmailsend_logcmd=${qmailsend_nologcmd}
        fi
-       command="@SETENV@ - ${qmailsend_postenv} qmail-start '$qmailsend_defaultdelivery' ${qmailsend_logcmd}"
+       command="@SETENV@ - ${qmailsend_postenv}
+qmail-start '$qmailsend_defaultdelivery'
+${qmailsend_logcmd}"
        command_args="&"
        rc_flags=""
 }
diff -r ed1c9cf3130e -r 0ebda0742c95 mail/qmail-run/files/qmailsmtpd.sh
--- a/mail/qmail-run/files/qmailsmtpd.sh        Mon Apr 10 13:24:55 2017 +0000
+++ b/mail/qmail-run/files/qmailsmtpd.sh        Mon Apr 10 15:04:56 2017 +0000
@@ -1,6 +1,6 @@
 #!@RCD_SCRIPTS_SHELL@
 #
-# $NetBSD: qmailsmtpd.sh,v 1.12 2017/04/09 12:58:46 schmonz Exp $
+# $NetBSD: qmailsmtpd.sh,v 1.13 2017/04/10 15:04:56 schmonz Exp $
 #
 # @PKGNAME@ script to control qmail-smtpd (SMTP service).
 #
@@ -46,10 +46,19 @@
        # tcpserver(1) is akin to inetd(8), but runs one service per process.
        # We want to signal only the tcpserver process responsible for SMTP
        # service. Use argv0(1) to set procname to "qmailsmtpd".
-       if [ -f /etc/rc.subr ]; then
-               checkyesno qmailsmtpd_log || qmailsmtpd_logcmd=${qmailsmtpd_nologcmd}
+       if [ -f /etc/rc.subr ] && ! checkyesno qmailsmtpd_log; then
+               qmailsmtpd_logcmd=${qmailsmtpd_nologcmd}
        fi
-       command="@SETENV@ - ${qmailsmtpd_postenv} @PREFIX@/bin/softlimit -m ${qmailsmtpd_datalimit} ${qmailsmtpd_pretcpserver} @PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name} ${qmailsmtpd_tcpflags} 
-x @PKG_SYSCONFDIR@/tcp.smtp.cdb -c `@HEAD@ -1 @PKG_SYSCONFDIR@/control/concurrencyincoming` -u `@ID@ -u @QMAIL_DAEMON_USER@` -g `@ID@ -g @QMAIL_DAEMON_USER@` ${qmailsmtpd_tcphost} 
${qmailsmtpd_tcpport} ${qmailsmtpd_presmtpd} ${qmailsmtpd_smtpdcmd} ${qmailsmtpd_postsmtpd} 2>&1 | @PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailsmtpd_logcmd}"
+       command="@SETENV@ - ${qmailsmtpd_postenv}
+@PREFIX@/bin/softlimit -m ${qmailsmtpd_datalimit} ${qmailsmtpd_pretcpserver}
+@PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name}
+${qmailsmtpd_tcpflags} -x @PKG_SYSCONFDIR@/tcp.smtp.cdb
+-c `@HEAD@ -1 @PKG_SYSCONFDIR@/control/concurrencyincoming`
+-u `@ID@ -u @QMAIL_DAEMON_USER@` -g `@ID@ -g @QMAIL_DAEMON_USER@`
+${qmailsmtpd_tcphost} ${qmailsmtpd_tcpport}
+${qmailsmtpd_presmtpd} ${qmailsmtpd_smtpdcmd} ${qmailsmtpd_postsmtpd}
+2>&1 |
+@PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailsmtpd_logcmd}"
        command_args="&"
        rc_flags=""
 }



Home | Main Index | Thread Index | Old Index
diff -r ed1c9cf3130e -r 0ebda0742c95 mail/qmail-run/files/qmailofmipd.sh
--- a/mail/qmail-run/files/qmailofmipd.sh       Mon Apr 10 13:24:55 2017 +0000
+++ b/mail/qmail-run/files/qmailofmipd.sh       Mon Apr 10 15:04:56 2017 +0000
@@ -1,6 +1,6 @@
 #!@RCD_SCRIPTS_SHELL@
 #
-# $NetBSD: qmailofmipd.sh,v 1.3 2017/04/09 12:58:46 schmonz Exp $
+# $NetBSD: qmailofmipd.sh,v 1.4 2017/04/10 15:04:56 schmonz Exp $
 #
 # @PKGNAME@ script to control ofmipd (SMTP submission service).
 #
@@ -44,12 +44,21 @@
 qmailofmipd_precmd()
 {
        # tcpserver(1) is akin to inetd(8), but runs one service per process.
        # We want to signal only the tcpserver process responsible for SMTP
        # service. Use argv0(1) to set procname to "qmailofmipd".
-       if [ -f /etc/rc.subr ]; then
-               checkyesno qmailofmipd_log || qmailofmipd_logcmd=${qmailofmipd_nologcmd}
+       if [ -f /etc/rc.subr ] && ! checkyesno qmailofmipd_log; then
+               qmailofmipd_logcmd=${qmailofmipd_nologcmd}
        fi
-       command="@SETENV@ - ${qmailofmipd_postenv} @PREFIX@/bin/softlimit -m ${qmailofmipd_datalimit} ${qmailofmipd_pretcpserver} @PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name} 
${qmailofmipd_tcpflags} -x @PKG_SYSCONFDIR@/tcp.ofmip.cdb -c `@HEAD@ -1 @PKG_SYSCONFDIR@/control/concurrencyofmip` -u `@ID@ -u @QMAIL_DAEMON_USER@` -g `@ID@ -g @QMAIL_DAEMON_USER@` 
${qmailofmipd_tcphost} ${qmailofmipd_tcpport} ${qmailofmipd_preofmipd} ${qmailofmipd_ofmipdcmd} ${qmailofmipd_postofmipd} 2>&1 | @PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailofmipd_logcmd}"
+       command="@SETENV@ - ${qmailofmipd_postenv}
+@PREFIX@/bin/softlimit -m ${qmailofmipd_datalimit} ${qmailofmipd_pretcpserver}
+@PREFIX@/bin/argv0 @PREFIX@/bin/tcpserver ${name}
+${qmailofmipd_tcpflags} -x @PKG_SYSCONFDIR@/tcp.ofmip.cdb
+-c `@HEAD@ -1 @PKG_SYSCONFDIR@/control/concurrencyofmip`
+-u `@ID@ -u @QMAIL_DAEMON_USER@` -g `@ID@ -g @QMAIL_DAEMON_USER@`
+${qmailofmipd_tcphost} ${qmailofmipd_tcpport}
+${qmailofmipd_preofmipd} ${qmailofmipd_ofmipdcmd} ${qmailofmipd_postofmipd}
+2>&1 |
+@PREFIX@/bin/setuidgid @QMAIL_LOG_USER@ ${qmailofmipd_logcmd}"
        command_args="&"
        rc_flags=""
 }
@@ -44,12 +44,21 @@
 {
        # tcpserver(1) is akin to inetd(8), but runs one service per process.
-       # We want to signal only the tcpserver process responsible for SMTP
+       # We want to signal only the tcpserver process responsible for OFMIP
        # service. Use argv0(1) to set procname to "qmailofmipd".